import {ProfilePicture} from '@caj/components/ProfilePicture';
import {TextSkeleton} from '@caj/components/simple/Skeleton';
import {defaultHeaderStyle} from '@caj/configs/colors';
import {SlideFromRightView} from '@caj/helper/animations';
import {RootState} from '@caj/redux/store';
import UserManager from '@caj/user/UserManager';
import {
  createNativeStackNavigator,
  NativeStackNavigationOptions,
  NativeStackNavigationProp,
} from '@react-navigation/native-stack';
import {Box, HStack, Text, VStack} from 'native-base';
import {Platform} from 'react-native';
import {useSelector} from 'react-redux';

export function ChatScreenOptions(): NativeStackNavigationOptions {
  const lang = useSelector((state: RootState) => state.appVariables.lang);
  const theme = useSelector(
    (state: RootState) => state.appVariables.preferences.theme,
  );
  const chatId = useSelector(
    (state: RootState) => state.nonSaveVariables.selectedChat,
  );
  const user = UserManager.getUserSelector(chatId);

  const platformUIFactor = Platform.OS === 'ios' ? 0.8 : 1;

  return {
    title: '',
    headerTitle: () => {
      return (
        <HStack space={2} alignItems="center" flex={1}>
          <ProfilePicture UserId={chatId} size={40 * platformUIFactor} />
          <VStack>
            <TextSkeleton
              SkeletonProps={{
                lines: 1,
                width: '160px',
              }}
              color="primary.400"
              fontSize={16 * platformUIFactor}>
              {user.Username.data}
            </TextSkeleton>
            <TextSkeleton
              SkeletonProps={{
                lines: 1,
                width: '140px',
              }}
              color="white.600"
              fontSize={16 * platformUIFactor}>
              {user.AccountName.data}
            </TextSkeleton>
          </VStack>
        </HStack>
      );
    },
    animation: 'slide_from_right',
    headerShown: true,

    ...defaultHeaderStyle(theme),
  };
}

function ChatMainScreen() {
  const chatId = useSelector(
    (state: RootState) => state.nonSaveVariables.selectedChat,
  );

  return (
    <Box backgroundColor={'blackBG.400'} height="10000px">
      {' '}
    </Box>
  );
}

export default ChatMainScreen;
