import {filterParam, getAllEntries, getEntry} from '../get';
import {DBMigration} from '../migration';
import {setEntry} from '../set';

import {databaseConf, possibleDBKeys} from '../types';

enum keys {
  UserId = 'a',
  msg = 'b',
}

const name = 'chat';
const primaryKey: keyof typeof propsDefault = keys.UserId;

const propsType: {[key in keyof typeof propsDefault]: string} = {
  [keys.UserId]: 'string',
  [keys.msg]: 'string',
};

const propsDefault = {
  [keys.UserId]: 'test',
  [keys.msg]: 'test',
};

const thisSchema: databaseConf<typeof propsDefault, typeof keys> = {
  filePath: name,
  version: 1,
  keys,
  migration: () => {
    return DBMigration[name](thisSchema);
  },
  setEntry: (val: typeof thisSchema.defaultProps) => {
    return setEntry<typeof thisSchema, typeof thisSchema.defaultProps>(
      thisSchema,
      val,
    );
  },
  getEntry: (key: possibleDBKeys) => {
    return getEntry<typeof thisSchema, typeof thisSchema.defaultProps>(
      thisSchema,
      key,
    );
  },
  getAllEntries: (filter?: filterParam) => {
    return getAllEntries<typeof thisSchema, typeof thisSchema.defaultProps>(
      thisSchema,
      filter,
    );
  },
  defaultProps: propsDefault,
  details: {
    name,
    properties: propsType,
    primaryKey,
  },
};

export default thisSchema;
