import AccountInfoBanner, {
  MyUserAccountInfoBanner,
} from '@caj/components/userUI/AccountInfoBanner';
import NotLoggedIn from '@caj/components/NotLoggedIn';
import {ThemeMode} from '@caj/configs/appVar';
import {defaultHeaderStyle} from '@caj/configs/colors';
import {RootStackNavigatorParamList} from '@caj/Navigation';
import {RootState} from '@caj/redux/store';
import {
  createNativeStackNavigator,
  NativeStackNavigationProp,
} from '@react-navigation/native-stack';
import {Box, Button, Center, Container, Text} from 'native-base';
import {useSelector} from 'react-redux';
import initChatDatabase from '@caj/components/chat/initChatDatabase';
import MyUserManager from '@caj/user/MyUserManager';
import {chatTags} from '@caj/components/chat/types';

export const AccountTabName = 'Account';

export type AccountStackNavigatorParamList = {
  Overview: undefined;
};

const AccountStack =
  createNativeStackNavigator<AccountStackNavigatorParamList>();

export type AccountScreenNavigationProp =
  NativeStackNavigationProp<AccountStackNavigatorParamList>;

function AccountTab() {
  const lang = useSelector((state: RootState) => state.appVariables.lang);
  const theme = useSelector(
    (state: RootState) => state.appVariables.preferences.theme,
  );

  return (
    <AccountStack.Navigator>
      <AccountStack.Screen
        name="Overview"
        options={{
          animation: 'slide_from_left',
          title: lang.navigation.home.account,
          headerShown: true,
          ...defaultHeaderStyle(theme),
        }}
        component={AccountScreen}
      />
    </AccountStack.Navigator>
  );
}

function AccountScreen() {
  const theme = useSelector(
    (state: RootState) => state.appVariables.preferences.theme,
  );
  return (
    <>
      <Box
        bg="blackBG.400"
        {...(theme === ThemeMode.Darkest
          ? {borderBottomWidth: 1, borderColor: 'white.900'}
          : {})}
        style={{
          width: '100%',
          paddingVertical: 20,
          borderBottomLeftRadius: 20,
        }}>
        <MyUserAccountInfoBanner />
      </Box>
      <NotLoggedIn />
      <Center mt={100}>
        <Button
          w="72"
          colorScheme="primary"
          rounded="xl"
          _text={{fontSize: 'xl'}}
          onPress={() => {
            initChatDatabase({
              roomId: MyUserManager.getSelectedUserId(),
              users: [MyUserManager.getSelectedUserId()],
              initSyncId: 0,
              syncId: 10,

              tags: [chatTags.GOOD_FRIEND],
              unreadMessages: 1234,
              timestamp: new Date().getTime() / 1000,
            });

            initChatDatabase({
              roomId: 'test',
              users: ['test'],
              initSyncId: 0,
              syncId: 0,
              tags: [chatTags.GROUP, chatTags.GOOD_FRIEND, chatTags.FRIEND],
              unreadMessages: 0,
              timestamp: new Date().getTime() / 1000,
            });

            initChatDatabase({
              roomId: '88139d16-acb1-410e-91a8-827ee8533c09',
              users: ['88139d16-acb1-410e-91a8-827ee8533c09'],
              initSyncId: 0,
              syncId: 0,
              tags: [chatTags.FRIEND],
              unreadMessages: 0,
              timestamp: new Date().getTime() / 1000,
            });
          }}>
          Init Chats
        </Button>
      </Center>
    </>
  );
}

export default AccountTab;
