import {ListChats} from '@caj/components/chat/listChats';
import ChatScreenStack, {
  ChatScreenOptions,
} from '@caj/components/chat/screen/main';
import NotLoggedIn from '@caj/components/NotLoggedIn';
import {defaultHeaderStyle} from '@caj/configs/colors';
import {
  HomeScreenNavigationProp,
  RootStackNavigatorParamList,
  WebBackButtonOptions,
} from '@caj/Navigation';
import {RootState} from '@caj/redux/store';
import {NavigatorScreenParams, useNavigation} from '@react-navigation/native';
import {
  createNativeStackNavigator,
  NativeStackNavigationProp,
} from '@react-navigation/native-stack';
import {Center, Text} from 'native-base';
import {useSelector} from 'react-redux';

export const ChatTabName = 'Chat';

export type ChatStackNavigatorParamList = {
  Overview: undefined;
  Chat: undefined;
};

const ChatStack = createNativeStackNavigator<ChatStackNavigatorParamList>();

export type ChatScreenNavigationProp =
  NativeStackNavigationProp<ChatStackNavigatorParamList>;

function ChatTab() {
  const lang = useSelector((state: RootState) => state.appVariables.lang);
  const theme = useSelector(
    (state: RootState) => state.appVariables.preferences.theme,
  );

  const navigation = useNavigation<ChatScreenNavigationProp>();

  return (
    <ChatStack.Navigator initialRouteName="Overview">
      <ChatStack.Screen
        name="Overview"
        options={{
          title: lang.navigation.home.chat,
          headerShown: true,
          ...defaultHeaderStyle(theme),
        }}
        component={ChatScreen}
      />
      <ChatStack.Screen
        name="Chat"
        component={ChatScreenStack}
        options={{...ChatScreenOptions(), ...WebBackButtonOptions(navigation, theme)}}
      />
    </ChatStack.Navigator>
  );
}

function ChatScreen() {
  return (
    <Center>
      <ListChats />
      <NotLoggedIn />
    </Center>
  );
}

export default ChatTab;
